========
Cnc 2.5D
========

:date: 2013-06-04
:author: charlyoleg


2.5D and cuboid assembly are a good solution for automated fabrication.
The Python package cnc25d proposes some generic functions and design examples related to the 2.5D construction.

1. Generic functions
--------------------

Design a millable 2D outline with the cnc_cut_outline_.

.. _cnc_cut_outline : cnc_cut_outline.rst

Place a plank in a cuboid assembly with plank_place_.

.. _plank_place : plank_place.rst


2. Design examples
------------------

The piece of furniture box_wood_frame_ to pile-up.

.. _box_wood_frame : box_wood_frame.rst


